
History
=======

1.3 (2013-12-04)
----------------

- Add GenericSetup config to properly register the Browser Layer.
  [thet. 2013-10-15]

- Let lineage.themeselection work with Plone 4.3, where plone.app.theming has a
  combined Diazo and Skins control panel. Setting the skin through this
  controlpanel doesn't work at the moment, so these settings are hidden for
  now. Please set the skin in the settings tab of the @@edit page of the
  lineage subsite.
  [thet, 2013-10-14]


1.2
---

- added Diazo Theme Support
  [jensens, 2012-01-01]


1.1
---

- added manifest file [jensens]

- cleanup [thet]


1.0
---

* Make it work. [jensens, 2011-06-06]
